==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt_br/editor.php <==
<?PHP // $Id: editor.php,v 1.2 2004/05/17 07:10:58 moodler Exp $ 
      // editor.php - created with Moodle 1.2.1 (2004032500)


$string['about'] = 'Informaes sobre este editor';
$string['absbottom'] = 'Embaixo';
$string['absmiddle'] = 'No meio';
$string['address'] = 'Endereo';
$string['alignment'] = 'Alinhamento';
$string['alternatetext'] = 'Texto alternativo';
$string['baseline'] = 'Linha da base';
$string['bold'] = 'Negrito';
$string['borderthickness'] = 'Espessura das bordas';
$string['bottom'] = 'Fundo';
$string['browse'] = 'Procurar';
$string['cancel'] = 'Cancelar';
$string['cellpadding'] = 'Distncia entre o texto e as bordas';
$string['cellspacing'] = 'distncia entre clulas ';
$string['choosechar'] = 'Escolher caractere';
$string['chooseicon'] = 'Escolher imagem para inserir';
$string['close'] = 'Fechar';
$string['cols'] = 'Cols';
$string['copy'] = 'Copiar elemento selecionado';
$string['createfolder'] = 'Criar pasta';
$string['createlink'] = 'Inserir link web';
$string['cut'] = 'Cortar elemento selecionado';
$string['delete'] = 'Cancelar';
$string['filebrowser'] = 'Navegador de arquivos';
$string['forecolor'] = 'Cor das letras';
$string['heading'] = 'Titolo';
$string['height'] = 'Altura';
$string['hilitecolor'] = 'Cor do fundo';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Linha Horizontal';
$string['htmlmode'] = 'Passar ao codigo html';
$string['imageurl'] = 'Url da imagem';
$string['indent'] = 'Aumentar distncia da margem';
$string['insertchar'] = 'Inserir caractere especial';
$string['insertimage'] = 'Inserir imagem';
$string['insertlink'] = 'Inserir link';
$string['insertsmile'] = 'Inserir carinha';
$string['inserttable'] = 'Inserir tabela';
$string['italic'] = 'itlico';
$string['justifycenter'] = 'justificar ao centro';
$string['justifyfull'] = 'justificar completamente';
$string['justifyleft'] = 'justificar  esquerda';
$string['justifyright'] = 'justificar  direita';
$string['layout'] = 'Layout';
$string['left'] = 'Esquerda';
$string['linkproperties'] = 'Propriedades do link';
$string['linktarget'] = 'Target';
$string['linktargetblank'] = 'Nova janela';
$string['linktargetnone'] = 'Nenhum';
$string['linktargetother'] = 'Outro';
$string['linktargetself'] = 'Mesmo frame';
$string['linktargettop'] = 'Mesma janela';
$string['linktitle'] = 'Titulo';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centro';
$string['move'] = 'Mover';
$string['normal'] = 'Normal';
$string['notimage'] = 'O arquivo selecionado no  uma imagem';
$string['notset'] = 'No definido';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Listas Numeradas';
$string['outdent'] = 'Reduzir distncia da margem';
$string['paste'] = 'Colar';
$string['path'] = 'Caminho';
$string['percent'] = 'Porcentagem';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Aumentar o editor';
$string['preformatted'] = 'Formato predefinido';
$string['preview'] = 'Ver';
$string['properties'] = 'Propriedades';
$string['redo'] = 'Repetir a ltima ao';
$string['removelink'] = 'Remover link';
$string['rename'] = 'Mudar o nome';
$string['right'] = 'Direita';
$string['rows'] = 'Linhas';
$string['selection'] = 'Seleo';
$string['showhelp'] = 'Ajuda para utilizar o editor';
$string['size'] = 'Tamanho';
$string['spacing'] = 'Distncia';
$string['strikethrough'] = 'Riscado';
$string['subscript'] = 'ndice';
$string['superscript'] = 'Expoente';
$string['textindicator'] = 'Estilo atual';
$string['textmode'] = 'Voc est usando a modalidae TEXT. Use o boto [<>] para retornar  modalidade WYSIWYG.';
$string['texttop'] = 'Topo do texto';
$string['top'] = 'Topo';
$string['type'] = 'Tipo';
$string['underline'] = 'Sublinhar';
$string['undo'] = 'Cancelar a ltima ao';
$string['unorderedlist'] = 'Lista con marcadores (bullet)';
$string['upload'] = 'Enviar';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largura';
$string['zip'] = 'Zip';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt_br/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.4.1 (2004083101)


$string['about'] = 'Informaes sobre este editor';
$string['absbottom'] = 'Embaixo';
$string['middle'] = 'No meio';
$string['address'] = 'Endereo';
$string['alignment'] = 'Alinhamento';
$string['alternatetext'] = 'Texto alternativo';
$string['anchorhelp'] = 'Isto cria apenas uma ncora.  necessrio criar o link manualmente.';
$string['anchorname'] = 'Nome da ncora';
$string['anchors'] = 'ncora';
$string['baseline'] = 'Linha-base';
$string['bold'] = 'Negrito';
$string['borderthickness'] = 'Espessura das bordas';
$string['bottom'] = 'Fundo';
$string['browse'] = 'Procurar';
$string['cancel'] = 'Cancelar';
$string['cellpadding'] = 'Distncia entre o texto e as bordas';
$string['cellspacing'] = 'Distncia entre clulas ';
$string['choosechar'] = 'Escolher caractere';
$string['chooseicon'] = 'Escolher imagem para inserir';
$string['close'] = 'Fechar';
$string['cols'] = 'Cols';
$string['copy'] = 'Copiar elemento selecionado';
$string['createanchor'] = 'Criar ncora';
$string['createfolder'] = 'Criar pasta';
$string['createlink'] = 'Inserir link web';
$string['cut'] = 'Cortar elemento selecionado';
$string['delete'] = 'Cancelar';
$string['filebrowser'] = 'Navegador de arquivos';
$string['forecolor'] = 'Cor das letras';
$string['fullscreen'] = 'Editor tela inteira';
$string['heading'] = 'Ttulo';
$string['height'] = 'Altura';
$string['hilitecolor'] = 'Cor do fundo';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Linha Horizontal';
$string['htmlmode'] = 'Passar ao cdigo html';
$string['imageurl'] = 'URL da imagem';
$string['indent'] = 'Aumentar distncia da margem';
$string['insertchar'] = 'Inserir caractere especial';
$string['insertimage'] = 'Inserir imagem';
$string['insertlink'] = 'Inserir link';
$string['insertsmile'] = 'Inserir carinha';
$string['inserttable'] = 'Inserir tabela';
$string['italic'] = 'Itlico';
$string['justifycenter'] = 'Centralizar';
$string['justifyfull'] = 'Justificar';
$string['justifyleft'] = 'Alinhar  esquerda';
$string['justifyright'] = 'Alinhar  direita';
$string['layout'] = 'Layout';
$string['left'] = 'Esquerda';
$string['lefttoright'] = 'Da esquerda para a direita';
$string['linkproperties'] = 'Propriedades do link';
$string['linktarget'] = 'Target';
$string['linktargetblank'] = 'Nova janela';
$string['linktargetnone'] = 'Nenhum';
$string['linktargetother'] = 'Outro';
$string['linktargetself'] = 'Mesmo frame';
$string['linktargettop'] = 'Mesma janela';
$string['linktitle'] = 'Titulo';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centro';
$string['minimize'] = 'Minimizar editor';
$string['move'] = 'Mover';
$string['normal'] = 'Normal';
$string['notimage'] = 'O arquivo selecionado no  uma imagem';
$string['notset'] = 'No definido';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Listas Numeradas';
$string['outdent'] = 'Reduzir distncia da margem';
$string['paste'] = 'Colar';
$string['path'] = 'Caminho';
$string['percent'] = 'Porcentagem';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Aumentar o editor';
$string['preformatted'] = 'Formato predefinido';
$string['preview'] = 'Ver';
$string['properties'] = 'Propriedades';
$string['redo'] = 'Repetir a ltima ao';
$string['removelink'] = 'Remover link';
$string['rename'] = 'Mudar o nome';
$string['right'] = 'Direita';
$string['righttoleft'] = 'Da direita para a esquerda';
$string['rows'] = 'Linhas';
$string['selectcolor'] = 'Selecionar cor';
$string['selection'] = 'Seleo';
$string['showhelp'] = 'Ajuda para utilizar o editor';
$string['size'] = 'Tamanho';
$string['spacing'] = 'Distncia';
$string['strikethrough'] = 'Riscado';
$string['subscript'] = 'ndice';
$string['superscript'] = 'Expoente';
$string['textindicator'] = 'Estilo atual';
$string['textmode'] = 'Voc est usando a modalidae TEXTO. Use o boto [<>] para retornar  modalidade WYSIWYG.';
$string['texttop'] = 'Topo do texto';
$string['top'] = 'Topo';
$string['type'] = 'Tipo';
$string['underline'] = 'Sublinhar';
$string['undo'] = 'Cancelar a ltima ao';
$string['unorderedlist'] = 'Lista com marcadores';
$string['upload'] = 'Enviar';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largura';
$string['wordclean'] = 'Limpar o html do word';
$string['zip'] = 'Zip';

?>
